@@ -20,16 +20,3 @@ def gaussian2D(x,y,x0,y0,sigmax,sigmay,amp,theta=0):
     
     return amp*np.exp(-(a*np.square(x-x0) + 2*b*(x-x0)*(y-y0) + c*np.square(y-y0)))
 
-def disk2D(x,y,x0,y0,radius,amp):
-    """2D Disk"""
-    
-    out = np.ones(x.shape)*amp
-    
-    idx = x0-radius < x
-    idx *= x < x0+radius
-    idx = y0-radius < y
-    idx *= y < y0+radius
-    
-    out[idx] = 0
-    return out
-
